pub struct FlatDescriptor {
pub type: String,
pub label: String,
pub description: Option<String>,
}Fields
type: Stringlabel: Stringdescription: Option<String>Trait Implementations
Sourceimpl Clone for FlatDescriptor
impl Clone for FlatDescriptor
Sourcefn clone(&self) -> FlatDescriptor
fn clone(&self) -> FlatDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlatDescriptor
impl Debug for FlatDescriptor
Sourceimpl<'de> Deserialize<'de> for FlatDescriptor
impl<'de> Deserialize<'de> for FlatDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlatDescriptor
impl JsonSchema for FlatDescriptor
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FlatDescriptor
impl RefUnwindSafe for FlatDescriptor
impl Send for FlatDescriptor
impl Sync for FlatDescriptor
impl Unpin for FlatDescriptor
impl UnwindSafe for FlatDescriptor