pub struct StructDescriptor {
pub type: String,
pub label: String,
pub members: Vec<FlatDescriptor>,
}Fields
type: Stringlabel: Stringmembers: Vec<FlatDescriptor>Trait Implementations
Sourceimpl Clone for StructDescriptor
impl Clone for StructDescriptor
Sourcefn clone(&self) -> StructDescriptor
fn clone(&self) -> StructDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructDescriptor
impl Debug for StructDescriptor
Sourceimpl<'de> Deserialize<'de> for StructDescriptor
impl<'de> Deserialize<'de> for StructDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StructDescriptor
impl JsonSchema for StructDescriptor
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StructDescriptor
impl RefUnwindSafe for StructDescriptor
impl Send for StructDescriptor
impl Sync for StructDescriptor
impl Unpin for StructDescriptor
impl UnwindSafe for StructDescriptor